function [C0, est] = pad2(n, xi1, xi2, wxi, f)
% [C0, est] = pad2(n, xi1, xi2, wxi, family, f)
%
% Interpolation coefficients
%
% n      = interpolation degree
% xi1    = the x values of Xu points.
% xi2    = the y values of Xu points.
% wxi    = the weights associated to each Padua point.
% family = family of Padua points.
% f      = function values at Xu points
%
% C0     = coefficients matrix
% est    = estimated error
[Txi1, Txi2] = cheb(n, xi1, xi2);
C0 = Txi1.*repmat(wxi.*f,n+1,1)*Txi2';
family = getfamily(xi1,n);
if (strcmp(family,'Padua1') | strcmp(family,'Padua3'))
  C0(n+1,1) = C0(n+1,1)/2;
elseif(strcmp(family,'Padua2') | strcmp(family,'Padua4'))
  C0(1,n+1) = C0(1,n+1)/2;
end
C0 = fliplr(C0);
est = 2*(norm(diag(C0),1)+norm(diag(C0,1),1)+norm(diag(C0,2),1));
C0 = fliplr(triu(C0));


