function [xi1, xi2, wxi] = xupts(n, varargin)
% [xi1, xi2, wxi] = xupts(n, vertex)
%
% Builds Xu points of n-th degree.
%
% n      = the degree of the Xu points. Must be a positive integer.
% vertex = a string describing where the vertex points are. Possible 
%          values are: 'TL' (topleft), 'TR' (topright). 
%          OPTIONAL. If omitted, 'TR' is assumed. Not used if n is even.
%
% xi1    = the x values of Xu points.
% xi2    = the y values of Xu points.
% wxi    = the weights associated to each Xu point.

if (~isPosInteger(n))
  error('n must be a positive integer.')
end

if (nargin == 1)
  vertex = 'TR';
elseif (nargin == 2)
  vertex = varargin{1};
else
  error('Wrong parameters number.');
end
z = cos([0:n] * pi / n);
if mod(n,2)
  if (strcmp(vertex, 'TL') | strcmp(vertex, 'BR'))
    [xi1, xi2, wxi] = xupts2(n);
  else
    [xi1, xi2, wxi] = xupts1(n);
  end  
else
  [xu1,yu1] = meshgrid(z(1:2:n+1),z(2:2:n+1));
  [xu2,yu2] = meshgrid(z(2:2:n+1),z(1:2:n+1));
  xi1 = [reshape(xu1,1,(n / 2 + 1 )* n / 2) reshape(xu2,1,(n / 2 + 1 ) * n / 2)];
  xi2 = [reshape(yu1,1,(n / 2 + 1 )* n / 2) reshape(yu2,1,(n / 2 + 1 ) * n / 2)];
  n1 = (n + 2) / 2;
  wxi = [ones(1,n1 - 1) repmat(repmat(2,1,n1 - 1),1,n1 - 2) ones(1,n1 - 1)];
  wxi = [wxi repmat([1 repmat(2,1,n1 - 2) 1],1,n1 - 1)];
  wxi = wxi / n ^ 2;
end
